@@ -2,7 +2,7 @@
 pdb <- cranJuly2014
 
 \dontrun{
-  pdb <- pkgAvail(repos=c(CRAN="http://cran.revolutionanalytics.com"))
+  pdb <- pkgAvail(repos = c(CRAN="http://mran.microsoft.com"))
   
   
   # Overwrite pdb with development version of miniCRAN at github
