@@ -1,5 +1,5 @@
 \dontrun{
 getCranDescription(c("igraph", "ggplot2", "XML"), 
-  repos=c(CRAN="http://cran.revolutionanalytics.com")
+  repos = c(CRAN = "http://mran.microsoft.com")
 )
 }
